@@ -31,9 +31,9 @@
 #include <glib/gi18n-lib.h>
 
 #define THEME_PATH "/usr/share/livewp/theme"
-#define SHORT_TIMER 100 /* 100 milisecond */
-//#define LONG_TIMER 10*60*1000 /* 10 minutes */
-#define LONG_TIMER  10*1000 /* 10 minutes */
+#define SHORT_TIMER 50 /* 100 milisecond */
+//#define LONG_TIMER 5*60*1000 /* 10 minutes */
+#define LONG_TIMER  20*1000 /* 10 minutes */
 enum { SHORT_TIMER_TYPE, LONG_TIMER_TYPE };
 #define SKY_LEVEL 0 
 #define SUN_LEVEL 0 
@@ -51,13 +51,15 @@ struct _Animation_WallpaperPrivate
     gint short_timer;
     gchar *theme;
     gboolean visible;
+    gboolean rich_animation;
+    GtkWidget *main_widget;
+    GtkWidget *right_corner;
     AWallpaperPlugin *desktop_plugin;
 };
 
 struct _AWallpaperPlugin
 {
-    HDHomePluginItem hitem;
-    GObject *parent;
+    HDHomePluginItem parent;
     Animation_WallpaperPrivate *priv;
 };
 
