@@ -27,11 +27,9 @@
 gint 
 read_config(Animation_WallpaperPrivate *priv) {
 
-    GConfValue *value = NULL;
     GConfClient *gconf_client = NULL;
-    GSList *stlist = NULL;
-    GError *gerror = NULL;
     gchar *tmp = NULL;
+    GConfValue *value = NULL;
 
     gconf_client = gconf_client_get_default();
     if (!gconf_client) {
@@ -45,6 +43,13 @@ read_config(Animation_WallpaperPrivate *priv) {
         priv->theme = tmp;
     }else
         priv->theme = g_strdup("Modern");
+    /* get Rich animation default TRUE */
+    value = gconf_client_get(gconf_client, GCONF_KEY_RANIMATION, NULL);
+    if (value) {
+        priv->rich_animation = gconf_value_get_bool(value);
+        gconf_value_free(value);
+    } else
+        priv->rich_animation = TRUE;
 
     return 0;
 }
@@ -57,11 +62,18 @@ save_config(Animation_WallpaperPrivate *priv) {
     gconf_client = gconf_client_get_default();
     if (!gconf_client) {
         fprintf(stderr, _("Failed to initialize GConf. Quitting.\n"));
-        return -1;
+        return;
     }
     /* Save Weather source name. */
     if (priv->theme)
         gconf_client_set_string(gconf_client,
                   GCONF_KEY_THEME,
                   priv->theme, NULL);
+    if (priv->rich_animation)
+        gconf_client_set_bool(gconf_client,
+                              GCONF_KEY_RANIMATION, TRUE, NULL);
+    else
+        gconf_client_set_bool(gconf_client,
+                              GCONF_KEY_RANIMATION, FALSE, NULL);
+
 }
